==> DateTime-Locale-1.32.tar.gz: DateTime-Locale-1.32/share/sd.pl <==
{
  am_pm_abbreviated => [
    "\N{U+0635}\N{U+0628}\N{U+062d}\N{U+060c} \N{U+0645}\N{U+0646}\N{U+062c}\N{U+0647}\N{U+0646}\N{U+062f}",
    "\N{U+0634}\N{U+0627}\N{U+0645}\N{U+060c} \N{U+0645}\N{U+0646}\N{U+062c}\N{U+0647}\N{U+0646}\N{U+062f}",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d, E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "MM-dd, E",
    MMM => "LLL",
    MMMEd => "MMM d, E",
    "MMMMW-count-one" => "\N{U+06be}\N{U+0641}\N{U+062a}\N{U+0648} W \N{U+062c}\N{U+0648} MMMM",
    "MMMMW-count-other" => "\N{U+06be}\N{U+0641}\N{U+062a}\N{U+0648} W \N{U+062c}\N{U+0648} MMMM",
    MMMMd => "MMMM d",
    MMMd => "MMM d",
    Md => "MM-dd",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "y-MM",
    yMEd => "y-MM-dd, E",
    yMMM => "y MMM",
    yMMMEd => "y MMM d, E",
    yMMMM => "y MMMM",
    yMMMd => "y MMM d",
    yMd => "y-MM-dd",
    yQQQ => "y QQQ",
    yQQQQ => "y QQQQ",
    "yw-count-one" => "\N{U+06be}\N{U+0641}\N{U+062a}\N{U+0648} w \N{U+062c}\N{U+0648} Y",
    "yw-count-other" => "\N{U+06be}\N{U+0641}\N{U+062a}\N{U+0648} w \N{U+062c}\N{U+0648} Y",
  },
  code => "sd",
  date_format_full => "y MMMM d, EEEE",
  date_format_long => "y MMMM d",
  date_format_medium => "y MMM d",
  date_format_short => "y-MM-dd",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "\N{U+0633}\N{U+0648}\N{U+0645}\N{U+0631}",
    "\N{U+0627}\N{U+06b1}\N{U+0627}\N{U+0631}\N{U+0648}",
    "\N{U+0627}\N{U+0631}\N{U+0628}\N{U+0639}",
    "\N{U+062e}\N{U+0645}\N{U+064a}\N{U+0633}",
    "\N{U+062c}\N{U+0645}\N{U+0639}\N{U+0648}",
    "\N{U+0687}\N{U+0646}\N{U+0687}\N{U+0631}",
    "\N{U+0622}\N{U+0686}\N{U+0631}",
  ],
  day_format_narrow => [
    "\N{U+0633}\N{U+0648}",
    "\N{U+0627}\N{U+06b1}\N{U+0627}\N{U+0631}\N{U+0648}",
    "\N{U+0627}\N{U+0631}\N{U+0628}\N{U+0639}",
    "\N{U+062e}\N{U+0645}",
    "\N{U+062c}\N{U+0645}\N{U+0639}\N{U+0648}",
    "\N{U+0687}\N{U+0646}\N{U+0687}\N{U+0631}",
    "\N{U+0622}\N{U+0686}\N{U+0631}",
  ],
  day_format_wide => [
    "\N{U+0633}\N{U+0648}\N{U+0645}\N{U+0631}",
    "\N{U+0627}\N{U+06b1}\N{U+0627}\N{U+0631}\N{U+0648}",
    "\N{U+0627}\N{U+0631}\N{U+0628}\N{U+0639}",
    "\N{U+062e}\N{U+0645}\N{U+064a}\N{U+0633}",
    "\N{U+062c}\N{U+0645}\N{U+0639}\N{U+0648}",
    "\N{U+0687}\N{U+0646}\N{U+0687}\N{U+0631}",
    "\N{U+0622}\N{U+0686}\N{U+0631}",
  ],
  day_stand_alone_abbreviated => [
    "\N{U+0633}\N{U+0648}\N{U+0645}\N{U+0631}",
    "\N{U+0627}\N{U+06b1}\N{U+0627}\N{U+0631}\N{U+0648}",
    "\N{U+0627}\N{U+0631}\N{U+0628}\N{U+0639}",
    "\N{U+062e}\N{U+0645}\N{U+064a}\N{U+0633}",
    "\N{U+062c}\N{U+0645}\N{U+0639}\N{U+0648}",
    "\N{U+0687}\N{U+0646}\N{U+0687}\N{U+0631}",
    "\N{U+0622}\N{U+0686}\N{U+0631}",
  ],
  day_stand_alone_narrow => [
    "\N{U+0633}\N{U+0648}",
    "\N{U+0627}\N{U+06b1}\N{U+0627}\N{U+0631}\N{U+0648}",
    "\N{U+0627}\N{U+0631}\N{U+0628}\N{U+0639}",
    "\N{U+062e}\N{U+0645}",
    "\N{U+062c}\N{U+0645}\N{U+0639}\N{U+0648}",
    "\N{U+0687}\N{U+0646}\N{U+0687}\N{U+0631}",
    "\N{U+0622}\N{U+0686}\N{U+0631}",
  ],
  day_stand_alone_wide => [
    "\N{U+0633}\N{U+0648}\N{U+0645}\N{U+0631}",
    "\N{U+0627}\N{U+06b1}\N{U+0627}\N{U+0631}\N{U+0648}",
    "\N{U+0627}\N{U+0631}\N{U+0628}\N{U+0639}",
    "\N{U+062e}\N{U+0645}\N{U+064a}\N{U+0633}",
    "\N{U+062c}\N{U+0645}\N{U+0639}\N{U+0648}",
    "\N{U+0687}\N{U+0646}\N{U+0687}\N{U+0631}",
    "\N{U+0622}\N{U+0686}\N{U+0631}",
  ],
  era_abbreviated => [
    "BC",
    "CD",
  ],
  era_narrow => [
    "BC",
    "CD",
  ],
  era_wide => [
    "\N{U+0642}\N{U+0628}\N{U+0644} \N{U+0645}\N{U+0633}\N{U+064a}\N{U+062d}",
    "\N{U+0639}\N{U+064a}\N{U+0633}\N{U+0648}\N{U+064a} \N{U+06a9}\N{U+0627}\N{U+0646} \N{U+067e}\N{U+0647}\N{U+0631}\N{U+064a}\N{U+0646}",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Sindhi",
  month_format_abbreviated => [
    "\N{U+062c}\N{U+0646}\N{U+0648}\N{U+0631}\N{U+064a}",
    "\N{U+0641}\N{U+064a}\N{U+0628}\N{U+0631}\N{U+0648}\N{U+0631}\N{U+064a}",
    "\N{U+0645}\N{U+0627}\N{U+0631}\N{U+0686}",
    "\N{U+0627}\N{U+067e}\N{U+0631}\N{U+064a}\N{U+0644}",
    "\N{U+0645}\N{U+0626}\N{U+064a}",
    "\N{U+062c}\N{U+0648}\N{U+0646}",
    "\N{U+062c}\N{U+0648}\N{U+0644}\N{U+0627}\N{U+0621}\N{U+0650}",
    "\N{U+0622}\N{U+06af}\N{U+0633}\N{U+067d}",
    "\N{U+0633}\N{U+064a}\N{U+067e}\N{U+067d}\N{U+0645}\N{U+0628}\N{U+0631}",
    "\N{U+0622}\N{U+06aa}\N{U+067d}\N{U+0648}\N{U+0628}\N{U+0631}",
    "\N{U+0646}\N{U+0648}\N{U+0645}\N{U+0628}\N{U+0631}",
    "\N{U+068a}\N{U+0633}\N{U+0645}\N{U+0628}\N{U+0631}",
  ],
  month_format_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_format_wide => [
    "\N{U+062c}\N{U+0646}\N{U+0648}\N{U+0631}\N{U+064a}",
    "\N{U+0641}\N{U+064a}\N{U+0628}\N{U+0631}\N{U+0648}\N{U+0631}\N{U+064a}",
    "\N{U+0645}\N{U+0627}\N{U+0631}\N{U+0686}",
    "\N{U+0627}\N{U+067e}\N{U+0631}\N{U+064a}\N{U+0644}",
    "\N{U+0645}\N{U+0626}\N{U+064a}",
    "\N{U+062c}\N{U+0648}\N{U+0646}",
    "\N{U+062c}\N{U+0648}\N{U+0644}\N{U+0627}\N{U+0621}\N{U+0650}",
    "\N{U+0622}\N{U+06af}\N{U+0633}\N{U+067d}",
    "\N{U+0633}\N{U+064a}\N{U+067e}\N{U+067d}\N{U+0645}\N{U+0628}\N{U+0631}",
    "\N{U+0622}\N{U+06aa}\N{U+067d}\N{U+0648}\N{U+0628}\N{U+0631}",
    "\N{U+0646}\N{U+0648}\N{U+0645}\N{U+0628}\N{U+0631}",
    "\N{U+068a}\N{U+0633}\N{U+0645}\N{U+0628}\N{U+0631}",
  ],
  month_stand_alone_abbreviated => [
    "\N{U+062c}\N{U+0646}\N{U+0648}\N{U+0631}\N{U+064a}",
    "\N{U+0641}\N{U+064a}\N{U+0628}\N{U+0631}\N{U+0648}\N{U+0631}\N{U+064a}",
    "\N{U+0645}\N{U+0627}\N{U+0631}\N{U+0686}",
    "\N{U+0627}\N{U+067e}\N{U+0631}\N{U+064a}\N{U+0644}",
    "\N{U+0645}\N{U+0626}\N{U+064a}",
    "\N{U+062c}\N{U+0648}\N{U+0646}",
    "\N{U+062c}\N{U+0648}\N{U+0644}\N{U+0627}\N{U+0621}\N{U+0650}",
    "\N{U+0622}\N{U+06af}\N{U+0633}\N{U+067d}",
    "\N{U+0633}\N{U+064a}\N{U+067e}\N{U+067d}\N{U+0645}\N{U+0628}\N{U+0631}",
    "\N{U+0622}\N{U+06aa}\N{U+067d}\N{U+0648}\N{U+0628}\N{U+0631}",
    "\N{U+0646}\N{U+0648}\N{U+0645}\N{U+0628}\N{U+0631}",
    "\N{U+068a}\N{U+0633}\N{U+0645}\N{U+0628}\N{U+0631}",
  ],
  month_stand_alone_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_stand_alone_wide => [
    "\N{U+062c}\N{U+0646}\N{U+0648}\N{U+0631}\N{U+064a}",
    "\N{U+0641}\N{U+064a}\N{U+0628}\N{U+0631}\N{U+0648}\N{U+0631}\N{U+064a}",
    "\N{U+0645}\N{U+0627}\N{U+0631}\N{U+0686}",
    "\N{U+0627}\N{U+067e}\N{U+0631}\N{U+064a}\N{U+0644}",
    "\N{U+0645}\N{U+0626}\N{U+064a}",
    "\N{U+062c}\N{U+0648}\N{U+0646}",
    "\N{U+062c}\N{U+0648}\N{U+0644}\N{U+0627}\N{U+0621}\N{U+0650}",
    "\N{U+0622}\N{U+06af}\N{U+0633}\N{U+067d}",
    "\N{U+0633}\N{U+064a}\N{U+067e}\N{U+067d}\N{U+0645}\N{U+0628}\N{U+0631}",
    "\N{U+0622}\N{U+06aa}\N{U+067d}\N{U+0648}\N{U+0628}\N{U+0631}",
    "\N{U+0646}\N{U+0648}\N{U+0645}\N{U+0628}\N{U+0631}",
    "\N{U+068a}\N{U+0633}\N{U+0645}\N{U+0628}\N{U+0631}",
  ],
  name => "Sindhi",
  native_language => "\N{U+0633}\N{U+0646}\N{U+068c}\N{U+064a}",
  native_name => "\N{U+0633}\N{U+0646}\N{U+068c}\N{U+064a}",
  native_script => undef,
  native_territory => undef,
  native_variant => undef,
  quarter_format_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q5",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "\N{U+067e}\N{U+0647}\N{U+0631}\N{U+064a}\N{U+0646} \N{U+067d}\N{U+064a} \N{U+0645}\N{U+0627}\N{U+0647}\N{U+064a}",
    "\N{U+067b}\N{U+064a}\N{U+0646} \N{U+067d}\N{U+064a} \N{U+0645}\N{U+0627}\N{U+0647}\N{U+064a}",
    "\N{U+067d}\N{U+064a}\N{U+0646} \N{U+067d}\N{U+064a} \N{U+0645}\N{U+0627}\N{U+0647}\N{U+064a}",
    "\N{U+0686}\N{U+0648}\N{U+067f}\N{U+064a}\N{U+0646} \N{U+067d}\N{U+064a} \N{U+0645}\N{U+0627}\N{U+0647}\N{U+064a}",
  ],
  quarter_stand_alone_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "\N{U+067e}\N{U+0647}\N{U+0631}\N{U+064a}\N{U+0646} \N{U+067d}\N{U+064a} \N{U+0645}\N{U+0627}\N{U+0647}\N{U+064a}",
    "\N{U+067b}\N{U+064a}\N{U+0646} \N{U+067d}\N{U+064a} \N{U+0645}\N{U+0627}\N{U+0647}\N{U+064a}",
    "\N{U+067d}\N{U+064a}\N{U+0646} \N{U+067d}\N{U+064a} \N{U+0645}\N{U+0627}\N{U+0647}\N{U+064a}",
    "\N{U+0686}\N{U+0648}\N{U+067f}\N{U+064a}\N{U+0646} \N{U+067d}\N{U+064a} \N{U+0645}\N{U+0627}\N{U+0647}\N{U+064a}",
  ],
  script => undef,
  territory => undef,
  time_format_full => "h:mm:ss a zzzz",
  time_format_long => "h:mm:ss a z",
  time_format_medium => "h:mm:ss a",
  time_format_short => "h:mm a",
  variant => undef,
  version => 39,
}

==> DateTime-Locale-1.41.tar.gz: DateTime-Locale-1.41/share/sd.pl <==
{
  am_pm_abbreviated => [
    "\N{U+0635}\N{U+0628}\N{U+062d}\N{U+060c}\N{U+202f}\N{U+0645}\N{U+0646}\N{U+062c}\N{U+0647}\N{U+0646}\N{U+062f}",
    "\N{U+0634}\N{U+0627}\N{U+0645}\N{U+060c}\N{U+202f}\N{U+0645}\N{U+0646}\N{U+062c}\N{U+0647}\N{U+0646}\N{U+062f}",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d, E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    GyMd => "M/d/y GGGGG",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "MM-dd, E",
    MMM => "LLL",
    MMMEd => "MMM d, E",
    "MMMMW-count-one" => "\N{U+06be}\N{U+0641}\N{U+062a}\N{U+0648} W \N{U+062c}\N{U+0648} MMMM",
    "MMMMW-count-other" => "\N{U+06be}\N{U+0641}\N{U+062a}\N{U+0648} W \N{U+062c}\N{U+0648} MMMM",
    MMMMd => "MMMM d",
    MMMd => "MMM d",
    Md => "MM-dd",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "y-MM",
    yMEd => "y-MM-dd, E",
    yMMM => "y MMM",
    yMMMEd => "y MMM d, E",
    yMMMM => "y MMMM",
    yMMMd => "y MMM d",
    yMd => "y-MM-dd",
    yQQQ => "y QQQ",
    yQQQQ => "y QQQQ",
    "yw-count-one" => "\N{U+06be}\N{U+0641}\N{U+062a}\N{U+0648} w \N{U+062c}\N{U+0648} Y",
    "yw-count-other" => "\N{U+06be}\N{U+0641}\N{U+062a}\N{U+0648} w \N{U+062c}\N{U+0648} Y",
  },
  code => "sd",
  date_format_full => "EEEE, MMMM d, y",
  date_format_long => "y MMMM d",
  date_format_medium => "y MMM d",
  date_format_short => "y-MM-dd",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "\N{U+0633}\N{U+0648}\N{U+0645}\N{U+0631}",
    "\N{U+0627}\N{U+06b1}\N{U+0627}\N{U+0631}\N{U+0648}",
    "\N{U+0627}\N{U+0631}\N{U+0628}\N{U+0639}",
    "\N{U+062e}\N{U+0645}\N{U+064a}\N{U+0633}",
    "\N{U+062c}\N{U+0645}\N{U+0639}\N{U+0648}",
    "\N{U+0687}\N{U+0646}\N{U+0687}\N{U+0631}",
    "\N{U+0622}\N{U+0686}\N{U+0631}",
  ],
  day_format_narrow => [
    "\N{U+0633}\N{U+0648}",
    "\N{U+0627}\N{U+06b1}\N{U+0627}\N{U+0631}\N{U+0648}",
    "\N{U+0627}\N{U+0631}\N{U+0628}\N{U+0639}",
    "\N{U+062e}\N{U+0645}",
    "\N{U+062c}\N{U+0645}\N{U+0639}\N{U+0648}",
    "\N{U+0687}\N{U+0646}\N{U+0687}\N{U+0631}",
    "\N{U+0622}\N{U+0686}\N{U+0631}",
  ],
  day_format_wide => [
    "\N{U+0633}\N{U+0648}\N{U+0645}\N{U+0631}",
    "\N{U+0627}\N{U+06b1}\N{U+0627}\N{U+0631}\N{U+0648}",
    "\N{U+0627}\N{U+0631}\N{U+0628}\N{U+0639}",
    "\N{U+062e}\N{U+0645}\N{U+064a}\N{U+0633}",
    "\N{U+062c}\N{U+0645}\N{U+0639}\N{U+0648}",
    "\N{U+0687}\N{U+0646}\N{U+0687}\N{U+0631}",
    "\N{U+0622}\N{U+0686}\N{U+0631}",
  ],
  day_stand_alone_abbreviated => [
    "\N{U+0633}\N{U+0648}\N{U+0645}\N{U+0631}",
    "\N{U+0627}\N{U+06b1}\N{U+0627}\N{U+0631}\N{U+0648}",
    "\N{U+0627}\N{U+0631}\N{U+0628}\N{U+0639}",
    "\N{U+062e}\N{U+0645}\N{U+064a}\N{U+0633}",
    "\N{U+062c}\N{U+0645}\N{U+0639}\N{U+0648}",
    "\N{U+0687}\N{U+0646}\N{U+0687}\N{U+0631}",
    "\N{U+0622}\N{U+0686}\N{U+0631}",
  ],
  day_stand_alone_narrow => [
    "\N{U+0633}\N{U+0648}",
    "\N{U+0627}\N{U+06b1}\N{U+0627}\N{U+0631}\N{U+0648}",
    "\N{U+0627}\N{U+0631}\N{U+0628}\N{U+0639}",
    "\N{U+062e}\N{U+0645}",
    "\N{U+062c}\N{U+0645}\N{U+0639}\N{U+0648}",
    "\N{U+0687}\N{U+0646}\N{U+0687}\N{U+0631}",
    "\N{U+0622}\N{U+0686}\N{U+0631}",
  ],
  day_stand_alone_wide => [
    "\N{U+0633}\N{U+0648}\N{U+0645}\N{U+0631}",
    "\N{U+0627}\N{U+06b1}\N{U+0627}\N{U+0631}\N{U+0648}",
    "\N{U+0627}\N{U+0631}\N{U+0628}\N{U+0639}",
    "\N{U+062e}\N{U+0645}\N{U+064a}\N{U+0633}",
    "\N{U+062c}\N{U+0645}\N{U+0639}\N{U+0648}",
    "\N{U+0687}\N{U+0646}\N{U+0687}\N{U+0631}",
    "\N{U+0622}\N{U+0686}\N{U+0631}",
  ],
  era_abbreviated => [
    "BC",
    "CD",
  ],
  era_narrow => [
    "BC",
    "CD",
  ],
  era_wide => [
    "\N{U+0642}\N{U+0628}\N{U+0644} \N{U+0645}\N{U+0633}\N{U+064a}\N{U+062d}",
    "\N{U+0639}\N{U+064a}\N{U+0633}\N{U+0648}\N{U+064a} \N{U+06a9}\N{U+0627}\N{U+0646} \N{U+067e}\N{U+0647}\N{U+0631}\N{U+064a}\N{U+0646}",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Sindhi",
  month_format_abbreviated => [
    "\N{U+062c}\N{U+0646}\N{U+0648}\N{U+0631}\N{U+064a}",
    "\N{U+0641}\N{U+064a}\N{U+0628}\N{U+0631}\N{U+0648}\N{U+0631}\N{U+064a}",
    "\N{U+0645}\N{U+0627}\N{U+0631}\N{U+0686}",
    "\N{U+0627}\N{U+067e}\N{U+0631}\N{U+064a}\N{U+0644}",
    "\N{U+0645}\N{U+0626}\N{U+064a}",
    "\N{U+062c}\N{U+0648}\N{U+0646}",
    "\N{U+062c}\N{U+0648}\N{U+0644}\N{U+0627}\N{U+0621}\N{U+0650}",
    "\N{U+0622}\N{U+06af}\N{U+0633}\N{U+067d}",
    "\N{U+0633}\N{U+064a}\N{U+067e}\N{U+067d}\N{U+0645}\N{U+0628}\N{U+0631}",
    "\N{U+0622}\N{U+06aa}\N{U+067d}\N{U+0648}\N{U+0628}\N{U+0631}",
    "\N{U+0646}\N{U+0648}\N{U+0645}\N{U+0628}\N{U+0631}",
    "\N{U+068a}\N{U+0633}\N{U+0645}\N{U+0628}\N{U+0631}",
  ],
  month_format_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_format_wide => [
    "\N{U+062c}\N{U+0646}\N{U+0648}\N{U+0631}\N{U+064a}",
    "\N{U+0641}\N{U+064a}\N{U+0628}\N{U+0631}\N{U+0648}\N{U+0631}\N{U+064a}",
    "\N{U+0645}\N{U+0627}\N{U+0631}\N{U+0686}",
    "\N{U+0627}\N{U+067e}\N{U+0631}\N{U+064a}\N{U+0644}",
    "\N{U+0645}\N{U+0626}\N{U+064a}",
    "\N{U+062c}\N{U+0648}\N{U+0646}",
    "\N{U+062c}\N{U+0648}\N{U+0644}\N{U+0627}\N{U+0621}\N{U+0650}",
    "\N{U+0622}\N{U+06af}\N{U+0633}\N{U+067d}",
    "\N{U+0633}\N{U+064a}\N{U+067e}\N{U+067d}\N{U+0645}\N{U+0628}\N{U+0631}",
    "\N{U+0622}\N{U+06aa}\N{U+067d}\N{U+0648}\N{U+0628}\N{U+0631}",
    "\N{U+0646}\N{U+0648}\N{U+0645}\N{U+0628}\N{U+0631}",
    "\N{U+068a}\N{U+0633}\N{U+0645}\N{U+0628}\N{U+0631}",
  ],
  month_stand_alone_abbreviated => [
    "\N{U+062c}\N{U+0646}\N{U+0648}\N{U+0631}\N{U+064a}",
    "\N{U+0641}\N{U+064a}\N{U+0628}\N{U+0631}\N{U+0648}\N{U+0631}\N{U+064a}",
    "\N{U+0645}\N{U+0627}\N{U+0631}\N{U+0686}",
    "\N{U+0627}\N{U+067e}\N{U+0631}\N{U+064a}\N{U+0644}",
    "\N{U+0645}\N{U+0626}\N{U+064a}",
    "\N{U+062c}\N{U+0648}\N{U+0646}",
    "\N{U+062c}\N{U+0648}\N{U+0644}\N{U+0627}\N{U+0621}\N{U+0650}",
    "\N{U+0622}\N{U+06af}\N{U+0633}\N{U+067d}",
    "\N{U+0633}\N{U+064a}\N{U+067e}\N{U+067d}\N{U+0645}\N{U+0628}\N{U+0631}",
    "\N{U+0622}\N{U+06aa}\N{U+067d}\N{U+0648}\N{U+0628}\N{U+0631}",
    "\N{U+0646}\N{U+0648}\N{U+0645}\N{U+0628}\N{U+0631}",
    "\N{U+068a}\N{U+0633}\N{U+0645}\N{U+0628}\N{U+0631}",
  ],
  month_stand_alone_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_stand_alone_wide => [
    "\N{U+062c}\N{U+0646}\N{U+0648}\N{U+0631}\N{U+064a}",
    "\N{U+0641}\N{U+064a}\N{U+0628}\N{U+0631}\N{U+0648}\N{U+0631}\N{U+064a}",
    "\N{U+0645}\N{U+0627}\N{U+0631}\N{U+0686}",
    "\N{U+0627}\N{U+067e}\N{U+0631}\N{U+064a}\N{U+0644}",
    "\N{U+0645}\N{U+0626}\N{U+064a}",
    "\N{U+062c}\N{U+0648}\N{U+0646}",
    "\N{U+062c}\N{U+0648}\N{U+0644}\N{U+0627}\N{U+0621}\N{U+0650}",
    "\N{U+0622}\N{U+06af}\N{U+0633}\N{U+067d}",
    "\N{U+0633}\N{U+064a}\N{U+067e}\N{U+067d}\N{U+0645}\N{U+0628}\N{U+0631}",
    "\N{U+0622}\N{U+06aa}\N{U+067d}\N{U+0648}\N{U+0628}\N{U+0631}",
    "\N{U+0646}\N{U+0648}\N{U+0645}\N{U+0628}\N{U+0631}",
    "\N{U+068a}\N{U+0633}\N{U+0645}\N{U+0628}\N{U+0631}",
  ],
  name => "Sindhi",
  native_language => "\N{U+0633}\N{U+0646}\N{U+068c}\N{U+064a}",
  native_name => "\N{U+0633}\N{U+0646}\N{U+068c}\N{U+064a}",
  native_script => undef,
  native_territory => undef,
  native_variant => undef,
  quarter_format_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q5",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "\N{U+067e}\N{U+0647}\N{U+0631}\N{U+064a}\N{U+0646} \N{U+067d}\N{U+064a} \N{U+0645}\N{U+0627}\N{U+0647}\N{U+064a}",
    "\N{U+067b}\N{U+064a}\N{U+0646} \N{U+067d}\N{U+064a} \N{U+0645}\N{U+0627}\N{U+0647}\N{U+064a}",
    "\N{U+067d}\N{U+064a}\N{U+0646} \N{U+067d}\N{U+064a} \N{U+0645}\N{U+0627}\N{U+0647}\N{U+064a}",
    "\N{U+0686}\N{U+0648}\N{U+067f}\N{U+064a}\N{U+0646} \N{U+067d}\N{U+064a} \N{U+0645}\N{U+0627}\N{U+0647}\N{U+064a}",
  ],
  quarter_stand_alone_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "\N{U+067e}\N{U+0647}\N{U+0631}\N{U+064a}\N{U+0646} \N{U+067d}\N{U+064a} \N{U+0645}\N{U+0627}\N{U+0647}\N{U+064a}",
    "\N{U+067b}\N{U+064a}\N{U+0646} \N{U+067d}\N{U+064a} \N{U+0645}\N{U+0627}\N{U+0647}\N{U+064a}",
    "\N{U+067d}\N{U+064a}\N{U+0646} \N{U+067d}\N{U+064a} \N{U+0645}\N{U+0627}\N{U+0647}\N{U+064a}",
    "\N{U+0686}\N{U+0648}\N{U+067f}\N{U+064a}\N{U+0646} \N{U+067d}\N{U+064a} \N{U+0645}\N{U+0627}\N{U+0647}\N{U+064a}",
  ],
  script => undef,
  territory => undef,
  time_format_full => "h:mm:ss a zzzz",
  time_format_long => "h:mm:ss a z",
  time_format_medium => "h:mm:ss a",
  time_format_short => "h:mm a",
  variant => undef,
  version => "44.1",
}
